/**
* 树表组件
* @author benzhan (詹潮江)
* @version 1.4.2
* @lastUpdateDate 2011-09-03
* @mail zhanchaojiang@qq.com
* @editor fyy 
* @lastUpdateDate 2021-06-02
* @mail support@fanyeyong.com
*/
(function ($) {
	window.SITE_URL = window.SITE_URL || '';
    if (document.location.href.indexOf('http://') != 0 || document.location.href.indexOf('https://') != 0)	{
        var path = '/js/treeTable/';
	} else {
        var path = SITE_URL + '/js/treeTable/';
    }

    var opts;
    var css;
    var pMap = {};
    var cMap = {};
    var openid_arr = [];
    var $treeTable;

    $.fn.extend({
        expandall: function () {
            opts.expandLevel = 10;
        }
    });

    $.fn.extend({
        expandbylevel: function (level) {
            opts.expandLevel = level;
        }
    });

    $.fn.extend({
        reset: function () {
            pMap = {};
            cMap = {};
        }
    });

    $.fn.extend({
        getopenids: function () {
            var openids = '';
            for (var i = 0; i < openid_arr.length; i++) {
                openids += (openids == '' ? '' : '$') + openid_arr[i];
            }

            return openids;
        }
    });

    $.fn.extend({
        setopen: function (openids) {
            var arr = openids.split('$');
            for (var i = 0; i < arr.length; i++) {
                openid_arr.push(arr[i]);
                $treeTable.nodeinit(openid_arr[i]);
            }
        }
    });

    $.fn.extend({
        opennode: function (id) {
            $('tr.' + id, $treeTable).show();
            if (!pMap[id]) {
                var firsttd = $('#' + id, $treeTable).children("td").eq(0);
                var $target = firsttd.children('span').eq(1);
                $target.attr('class', css['AN']);
                return false;
            }
            for (var i = 0; i < pMap[id].length; i++) {
                var cId = pMap[id][i];
                if (pMap[cId]) {
                    var className = $('#' + cId, $treeTable).find('.' + css['AN']).attr('class');
                    //如果子节点是展开图表的，则需要展开此节点
                    (className == css['AN'] + ' ' + css['O'] || className == css['AN'] + ' ' + css['LO']) && $treeTable.opennode(cId);
                }
            }
        }
    });

    $.fn.extend({
        nodeinit: function (id) {
            var firsttd = $('#' + id, $treeTable).children("td").eq(0);
            var $target = firsttd.children('span').eq(1);
            var className = $target.attr('class');
            $target.attr('class', css['AN'] + " " + css['O']);
            opts.beforeExpand($treeTable, id);

            if (openid_arr.indexOf(id) == -1) {
                openid_arr.push(id);
            }

            $treeTable.opennode(id);
        }
    });

    $.fn.extend({
        initRelation: function ($trs, hideLevel) {
            //构造父子关系
            $trs.each(function (i) {
                var pId = $(this).attr('pId') || 0;
                pMap[pId] || (pMap[pId] = []);
                pMap[pId].push(this.id);
                cMap[this.id] = pId;

                //给这个tr增加类为了提高选择器的效率
                $(this).addClass(pId);
            }).find('[controller]').css('cursor', 'pointer');

            //标识父节点是否有孩子、是否最后一个节点
            $trs.each(function (i) {
                if (!this.id) { return; }
                var $tr = $(this);

                $tr.removeAttr("hasChild");
                pMap[this.id] && $tr.attr('hasChild', true);

                var pArr = pMap[cMap[this.id]];
                if (pArr[0] == this.id) {
                    $tr.attr('isFirstOne', true);
                } else {
                    var prevId = 0;
                    for (var i = 0; i < pArr.length; i++) {
                        if (pArr[i] == this.id) { break; }
                        prevId = pArr[i];
                    }
                    $tr.attr('prevId', prevId);
                }

                pArr[pArr.length - 1] == this.id && $tr.attr('isLastOne', true);

                var depth = getDepth(this.id);
                $tr.attr('depth', depth);

                //格式化节点
                formatNode(this);

                //判断是否要隐藏限制的层次
                if (hideLevel) {
                    depth > opts.expandLevel && $tr.hide();
                    //判断是否小于深度，如果小于深度则要换成展开的图标
                    if ($tr.attr('hasChild') && $tr.attr('depth') < opts.expandLevel) {
                        var className = $tr.attr('isLastOne') ? css['LO'] : css['O'];
                        $tr.find('.' + css['AN']).attr('class', css['AN'] + ' ' + className);
                    }
                }
            });

            //递归获取深度
            function getDepth(id) {
                if (cMap[id] == 0) { return 1; }
                var $parentDepth = getDepth(cMap[id]);
                return $parentDepth + 1;
            }

            function formatNode(tr) {
                var $cur = $(tr);
                var id = tr.id;

                //-------------下面一大段都是获取$preSpan---------
                if (cMap[id] == 0) {
                    //如果是顶级节点，则没有prev_span
                    var $preSpan = $('<span class="prev_span"></span>');
                } else {
                    //先判断是否有上一个兄弟节点
                    if (!$cur.attr('isFirstOne')) {
                        var $preSpan = $('#' + $cur.attr('prevId'), $treeTable).children("td").eq(opts.column).find('.prev_span').clone();
                    } else {
                        var $parent = $('#' + cMap[id], $treeTable);
                        //没有上一个兄弟节点，则使用父节点的prev_span
                        var $preSpan = $parent.children("td").eq(opts.column).find('.prev_span').clone();

                        //如果父亲后面没有兄弟，则直接加空白，若有则加竖线
                        if ($parent.attr('isLastOne')) {
                            $preSpan.append('<span class="' + css['N'] + ' ' + css['B'] + '"></span>');
                        } else {
                            $preSpan.append('<span class="' + css['N'] + ' ' + css['V'] + '"></span>');
                        }
                    }
                }
                //------------------------------------------------

                if ($cur.attr('hasChild')) {
                    //如果有下一个节点，并且下一个节点的父亲与当前节点的父亲相同，则说明该节点不是最后一个节点
                    var className = $cur.attr('isLastOne') ? css['LS'] : css['S'];
                    className = css['AN'] + ' ' + className;
                } else {
                    var className = css['N'] + ' ' + ($cur.attr('isLastOne') ? css['LL'] : css['L']);
                }

                var $td = $cur.children("td").eq(opts.column);
                $td.prepend('<span arrow="true" class="' + className + '"></span>').prepend($preSpan);
            };
        }
    });

    $.fn.treeTable = function (option) {
        opts = $.extend({
            theme: 'default',
            expandLevel: 1,
            column: 0,
            onSelect: function($treeTable, id){},
            beforeExpand: function($treeTable, id){}
        }, option);

        $treeTable = this;
        $treeTable.addClass('tree_table');

        //添加需要的样式
        if ($('head').find('#tree_table_' + opts.theme).length == 0) {
            $('head').append('<link id="tree_table_' + opts.theme + '" href="' + path + opts.theme + '/jquery.treeTable.css" rel="stylesheet" type="text/css" />');
        }

        css = {
            'N' : opts.theme + '_node',
            'AN' : opts.theme + '_active_node',
            'O' : opts.theme + '_open',
            'LO' : opts.theme + '_last_open',
            'S' : opts.theme + '_shut',
            'LS' : opts.theme + '_last_shut',
            'HO' : opts.theme + '_hover_open',
            'HS' : opts.theme + '_hover_shut',
            'HLO' : opts.theme + '_hover_last_open',
            'HLS' : opts.theme + '_hover_last_shut',
            'L' : opts.theme + '_leaf',
            'LL' : opts.theme + '_last_leaf',
            'B' : opts.theme + '_blank',
            'V' : opts.theme + '_vertline'
        };

        $treeTable.click(function (event) {
            var $target = $(event.target);
            if ($target.attr('controller')) {
                $target = $target.parents('tr[haschild]').find('[arrow]');
                //判断是否是叶子节点
				if ($target.attr('class').indexOf(css['AN']) == -1 && $target.attr('class').indexOf(css['N']) == -1) { return; }
                var id = $target.parents('tr[haschild]')[0].id;
                if (opts.onSelect && opts.onSelect($treeTable, id) === false) { return; }
            }

            if ($target.attr('istitle') == '1') {
                var firsttd = $target.parent().children("td").eq(0);
                $target = firsttd.children('span').eq(1);
            }

            if ($target.attr('arrow')) {
                var className = $target.attr('class');
                if (className == css['AN'] + ' ' + css['O'] || className == css['AN'] + ' ' + css['LO'] || className == css['AN'] + ' ' + css['HLO'] || className == css['AN'] + ' ' + css['HO']) {
                    var id = $target.parents('tr[haschild]')[0].id;
                    $target.attr('class', css['AN'] + " " + (className.indexOf(css['HO']) != -1 ?  css['HS'] : css['HLS']));
                    var id_index = openid_arr.indexOf(id);
                    if (id_index > -1) {
                        openid_arr.splice(id_index,1);
                    }

                    //关闭所有孩子的tr
                    shut(id);
                    
					return;
                } else if (className == css['AN'] + ' ' + css['S'] || className == css['AN'] + ' ' + css['LS'] || className == css['AN'] + ' ' + css['HLS'] || className == css['AN'] + ' ' + css['HS']) {
                    var id = $target.parents('tr')[0].id;
                    $target.attr('class', css['AN'] + " " + (className.indexOf(css['HS']) != -1 ? css['HO'] : css['HLO']));
                    opts.beforeExpand($treeTable, id);

                    if (openid_arr.indexOf(id) == -1) {
                        openid_arr.push(id);
                    }
                    
                    //展开所有直属节点，根据图标展开子孙节点
                    $treeTable.opennode(id);
					return;
                }
            }
        });
		
		$treeTable.mouseover(hoverActiveNode).mouseout(hoverActiveNode);

        function hoverActiveNode(event) {
            var $target = $(event.target);

            if ($target.attr('controller')) {
                $target = $target.parents('tr[haschild]').find('[arrow]');
            }

            if ($target.attr('istitle') == '1') {
                var firsttd = $target.parent().children("td").eq(0);
                $target = firsttd.children('span').eq(1);
            }

            if ($target.attr('arrow')) { 
                var className = $target.attr('class');
                if (className && !className.indexOf(css['AN'])) {
                    var len = opts.theme.length + 1;
                    className = className.split(' ')[1].substr(len);
                    if (className.indexOf('hover_') === 0) {
                        className = opts.theme + '_' + className.substr(6);
                    } else {
                        className = opts.theme + '_hover_' + className;
                    }
                    
                    $target.attr('class', css['AN'] + ' ' + className);
                    return;
                }
            } 
        }

        //递归关闭所有的孩子
        function shut(id) {
            if (!pMap[id]) { return false; }
            for (var i = 0; i < pMap[id].length; i++) {
                shut(pMap[id][i]);
            }
            $('tr.' + id, $treeTable).hide();
        }

        return $treeTable;
    };
})(jQuery);

